@@ -19,10 +19,27 @@
 #' @param true The true standardized mean difference to which to shift the observed point estimate. Typically set to 0 to consider a null true effect. 
 #' @export
 #' @details 
+#' This function is for linear regression with a continuous exposure and outcome.
+#' Regarding the continuous exposure, the choice of \code{delta} defines essentially a 
+#' dichotomization in the exposure between hypothetical groups of subjects with exposures equal to an arbitrary
+#' value \emph{c} versus to another hypothetical group with exposures equal to \emph{c} + \code{delta}.
+#' Regarding the continuous outcome, the function uses the effect-size conversions in Chinn (2000)
+#' and VanderWeele (2017) to approximately convert the mean difference between these exposure "groups"
+#' to the odds ratio that would arise from dichotomizing the continuous outcome.
+#' 
+#' For example, if resulting E-value is 2, this means that unmeasured confounder(s) would need to double
+#' the probability of a subject's having exposure equal to \emph{c} + \code{delta} instead of \emph{c}, and would also need to
+#' double the probability of being high versus low on the outcome, in which the cutoff for "high" versus
+#' "low" is arbitrary subject to some distributional assumptions (Chinn, 2000). 
+#' 
 #' A true standardized mean difference for linear regression would use \code{sd} = SD(Y | X, C), where Y is
 #' the outcome, X is the exposure of interest, and C are any adjusted covariates. See Examples for how to extract 
 #' this from \code{lm}. A conservative approximation would instead use \code{sd} = SD(Y). Regardless, the reported E-value
 #' for the confidence interval treats \code{sd} as known, not estimated.  
+#' @references
+#' Chinn, S (2000). A simple method for converting an odds ratio to effect size for use in meta-analysis. \emph{Statistics in Medicine}, 19(22), 3127-3131.
+#'
+#' VanderWeele, TJ (2017). On a square-root transformation of the odds ratio for a common outcome. \emph{Epidemiology}, 28(6), e58.
 #' @examples
 #' # first standardizing conservatively by SD(Y)
 #' data(lead)
@@ -74,6 +91,19 @@ evalues.OLS = function( est, se = NA, sd, delta = 1, true = 0 ) {
 #' @param se The standard error of the point estimate
 #' @param true The true standardized mean difference to which to shift the observed point estimate. Typically set to 0 to consider a null true effect. 
 #' @export
+#' @details 
+#' Regarding the continuous outcome, the function uses the effect-size conversions in Chinn (2000)
+#' and VanderWeele (2017) to approximately convert the mean difference between the exposed versus unexposed groups
+#' to the odds ratio that would arise from dichotomizing the continuous outcome.
+#' 
+#' For example, if resulting E-value is 2, this means that unmeasured confounder(s) would need to double
+#' the probability of a subject's being exposed versus not being exposed, and would also need to
+#' double the probability of being high versus low on the outcome, in which the cutoff for "high" versus
+#' "low" is arbitrary subject to some distributional assumptions (Chinn, 2000). 
+#' @references 
+#' Chinn, S (2000). A simple method for converting an odds ratio to effect size for use in meta-analysis. \emph{Statistics in Medicine}, 19(22), 3127-3131.
+#'
+#' VanderWeele, TJ (2017). On a square-root transformation of the odds ratio for a common outcome. \emph{Epidemiology}, 28(6), e58.
 #' @examples
 #' # compute E-value if Cohen's d = 0.5 with SE = 0.25
 #' evalues.MD( .5, .25 )
@@ -657,11 +687,15 @@ confounded_meta = function( q, r=NA, muB=NA, sigB=0,
   # if tail isn't provided, assume user wants the more extreme one (away from the null)
   if ( is.na(tail) ) tail = ifelse( yr > log(1), "above", "below" )
   
+  # bias-corrected mean depends on whether yr is causative, NOT on the desired tail
+  if ( yr > log(1) ) yr.corr = yr - muB
+  else yr.corr = yr + muB
+  
   if ( tail == "above" ) {
     
     if ( !is.na(muB) ) {
       # prop above
-      Z = ( q + muB - yr ) / sqrt( t2 - sigB^2 )
+      Z = ( q - yr.corr ) / sqrt( t2 - sigB^2 )
       phat = 1 - pnorm(Z) 
     } else {
       phat = NA
@@ -687,7 +721,7 @@ confounded_meta = function( q, r=NA, muB=NA, sigB=0,
     
     if ( !is.na(muB) ) {
       # prop below
-      Z = ( q - muB - yr ) / sqrt( t2 - sigB^2 )
+      Z = ( q - yr.corr ) / sqrt( t2 - sigB^2 )
       phat = pnorm(Z) 
     } else {
       phat = NA
@@ -791,7 +825,7 @@ confounded_meta = function( q, r=NA, muB=NA, sigB=0,
 #' @param sigB Standard deviation of log bias factor across studies
 #' @param yr Pooled point estimate (on log scale) from confounded meta-analysis
 #' @param t2 Estimated heterogeneity (tau^2) from confounded meta-analysis
-#' @keywords meta-analysis, confounding, sensitivity
+#' @keywords meta-analysis confounding sensitivity
 #' @export
 #' @details
 #' For \code{meas=="Tmin"} or \code{meas=="Gmin"}, arguments \code{muB} and
@@ -900,7 +934,7 @@ sens_table = function( meas, q, r=seq(0.1, 0.9, 0.1), muB=NA, sigB=NA,
 #' @param breaks.x1 Breaks for lower X-axis (bias factor) on RR scale (optional for line plot; not used for distribution plot)
 #' @param breaks.x2 Breaks for upper X-axis (confounding strength) on RR scale (optional for line plot; not used for distribution plot)
 #' @param CI.level Pointwise confidence level as a proportion
-#' @keywords meta-analysis, confounding, sensitivity
+#' @keywords meta-analysis confounding sensitivity
 #' @details
 #' Arguments \code{vyr} and \code{vt2} can be left \code{NA}, in which case no confidence
 #' band will appear on the line plot. 
@@ -1011,8 +1045,11 @@ sens_plot = function( type, q, muB=NA, Bmin=log(1), Bmax=log(5), sigB=0,
     } )
     
     p = ggplot2::ggplot( t, aes(x=t$eB, y=t$phat ) ) + theme_bw() +
-      scale_y_continuous( limits=c(0,1), breaks=seq(0, 1, .1)) +
-      scale_x_continuous(  breaks = breaks.x1,
+      scale_y_continuous( limits=c(0,1),
+                          breaks=seq(0, 1, .1) ) +
+      scale_x_continuous(  limits = c(min(breaks.x1), 
+                                      max(breaks.x1)),
+                           breaks = breaks.x1,
                            sec.axis = sec_axis( ~ g(.),  # confounding strength axis
                                                 name = "Minimum strength of both confounding RRs",
                                                 breaks=breaks.x2 ) ) +
